# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

%define major   1
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%define libver  %(echo %{version} | cut -d'.' -f-3)

%define uname   Vulkan-Loader

Name:           vulkan-loader
Version:        1.3.296.0
Release:        %mkrel 1
Summary:        Vulkan ICD desktop loader
Group:          System/Libraries
License:        ASL 2.0
URL:            https://github.com/KhronosGroup/Vulkan-Loader
Source0:        https://github.com/KhronosGroup/Vulkan-Loader/archive/vulkan-sdk-%{version}/%{uname}-sdk-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  python3-devel
BuildRequires:  vulkan-headers = %{version}

%description
This project provides the Khronos official Vulkan ICD desktop
loader for Windows, Linux, and MacOS.

%package -n %{libname}
Summary:        Library files for the Vulkan ICD loader
Group:          System/Libraries

%description -n %{libname}
Library files for the Vulkan ICD loader.

%package -n %{devname}
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}-%{release}
Requires:       vulkan-headers >= %{version}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       vulkan-devel = %{version}-%{release}

%description -n %{devname}
This package contains libraries and header files for developing
applications that use the Vulkan ICD loader.

%prep
%autosetup -p1 -n %{uname}-vulkan-sdk-%{version}

%build
%cmake -GNinja
%cmake_build

%install
%cmake_install

# create the filesystem
install -d \
    %{buildroot}%{_sysconfdir}/vulkan/{explicit_layer,implicit_layer,icd}.d/ \
    %{buildroot}%{_datadir}/vulkan/{explicit_layer,implicit_layer,icd}.d/

%files -n %{libname}
%doc README.md CONTRIBUTING.md
%license LICENSE.txt
%dir %{_sysconfdir}/vulkan
%dir %{_sysconfdir}/vulkan/explicit_layer.d
%dir %{_sysconfdir}/vulkan/icd.d
%dir %{_sysconfdir}/vulkan/implicit_layer.d
%dir %{_datadir}/vulkan
%dir %{_datadir}/vulkan/explicit_layer.d
%dir %{_datadir}/vulkan/icd.d
%dir %{_datadir}/vulkan/implicit_layer.d
%{_libdir}/libvulkan.so.%{major}
%{_libdir}/libvulkan.so.%{libver}

%files -n %{devname}
%{_libdir}/pkgconfig/vulkan.pc
%{_libdir}/cmake/VulkanLoader/
%{_libdir}/libvulkan.so


%changelog
* Fri Nov 15 2024 daviddavid <daviddavid> 1.3.296.0-1.mga10
+ Revision: 2116055
- update to 1.3.296.0 SDK

* Tue Aug 20 2024 daviddavid <daviddavid> 1.3.290.0-1.mga10
+ Revision: 2087091
- update to 1.3.290.0 SDK

* Mon Apr 10 2023 daviddavid <daviddavid> 1.3.231.1-2.mga9
+ Revision: 1951893
- rebuild to fix 'libdir' path in pkgconfig file

* Mon Nov 14 2022 akien <akien> 1.3.231.1-1.mga9
+ Revision: 1907190
- Vulkan SDK 1.3.231.1

* Wed Mar 30 2022 umeabot <umeabot> 1.3.204.1-2.mga9
+ Revision: 1834393
- Mageia 9 Mass Rebuild

* Mon Mar 07 2022 akien <akien> 1.3.204.1-1.mga9
+ Revision: 1789533
- Vulkan SDK 1.3.204.1
- Add notice about Vulkan SDK update instructions in vulkan-headers

* Wed Dec 30 2020 luigiwalser <luigiwalser> 1.2.162.0-1.mga8
+ Revision: 1666098
- 1.2.162.0
- remove upstreamed patch

* Mon Oct 12 2020 akien <akien> 1.2.154.1-2.mga8
+ Revision: 1633973
- Fix pkgconfig libdir

* Mon Oct 12 2020 akien <akien> 1.2.154.1-1.mga8
+ Revision: 1633940
- SDK 1.2.154.1

* Mon Feb 17 2020 akien <akien> 1.2.131.2-1.mga8
+ Revision: 1536926
- SDK 1.2.131.2

* Sun Feb 16 2020 daviddavid <daviddavid> 1.1.121.0-2.mga8
+ Revision: 1533969
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Sep 25 2019 akien <akien> 1.1.121.0-1.mga8
+ Revision: 1445842
- SDK 1.1.121.0

* Thu Apr 18 2019 akien <akien> 1.1.106.0-1.mga7
+ Revision: 1393160
- SDK 1.1.106.0

* Tue Mar 26 2019 akien <akien> 1.1.101.0-1.mga7
+ Revision: 1380453
- SDK 1.1.101.0
- Provide vulkan-loader-devel in dev package

* Mon Dec 10 2018 akien <akien> 1.1.92.0-1.mga7
+ Revision: 1340024
- Adapt to Mageia library policy (lib package with major 1)
- Simplify spec file
- Fix support for building ASM components
- import vulkan-loader from Fedora Rawhide


* Mon Dec 03 2018 Dave Airlie <airlied@redhat.com> - 1.1.92.0-1
- Update to 1.1.92.0

* Mon Nov 19 2018 Dave Airlie <airlied@redhat.com> - 1.1.85.0-1
- Update to 1.1.85.0

* Tue Aug 07 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.82.0-1
- Update to 1.1.82.0

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.77.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Jun 27 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.77.0-4
- Fix update path

* Tue Jun 26 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.77.0-3
- Add conditional for mesa-vulkan-drivers requires

* Tue Jun 26 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.77.0-2
- Improve description and summary
- Set release

* Sat Jun 23 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.1.77.0-1
- Initial package
